
#include <stdio.h>
#include <string.h>

#include "cow.h"

gint total_len = 30000;
gint loop_len = 1000;
gint step_size = 10;
gint mem_size = 1000;
gint share_chance = 10;


GimpMemPtr * p;


int
main (int    argc,
      char **argv)
{
  int i, j;

  gimp_memory_init ("foobar");
  
  g_warning ("create pointers");
  p = g_new (GimpMemPtr, total_len);
  for (i = 0; i < total_len; i++)
    {
      d_init (&p[i]);
    }

  g_warning ("alloc/share pointers");
  for (i = 0; i < total_len; i++)
    {
      if ((i+1) % share_chance)
        d_alloc (&p[i], mem_size);
      else
        d_join (&p[0], &p[i]);
    }

  while (1)
    {
      for (i = 0; i < total_len; i += step_size)
        {
          g_warning ("read %d", i);
          for (j = 0; j < loop_len; j ++)
            {
              d_read (&p[(i+j)%total_len]);
            }
          g_warning ("release");
          for (j = 0; j < loop_len; j ++)
            {
              d_release (&p[(i+j)%total_len]);
            }
        }
    }
  
  return 0;
}


